<a href="https://github.com/Aarhus-Psychiatry-Research/psycop-feature-generation"><img src="https://github.com/Aarhus-Psychiatry-Research/psycop-ml-utils/blob/main/docs/_static/icon_with_title.png?raw=true" width="220" align="right"/></a>

# PSYCOP utilities for feature generation

[![PyPI version](https://badge.fury.io/py/psycop-feature-generation.svg)](https://pypi.org/project/psycop-feature-generation/)
![python versions](https://img.shields.io/badge/Python-%3E=3.10-blue)
[![Code style: black](https://img.shields.io/badge/Code%20Style-Black-black)](https://black.readthedocs.io/en/stable/the_black_code_style/current_style.html)
[![github actions pytest](https://github.com/Aarhus-Psychiatry-Research/psycop-feature-generation/actions/workflows/main_test_and_release.yml/badge.svg)](https://github.com/Aarhus-Psychiatry-Research/psycop-feature-generation/actions)

## 🔧 Installation
To get started using psycop-feature-generation simply install it using pip by running the following line in your terminal:

```
pip install psycop-feature-generation
```

## 🎓 Project
PSYCOP projects which use `psycop-feature-generation`.

| Project                | Publications |     |
| -----------------------|----------| ---------------------------------------------------------------------------------- |
| **[Type 2 Diabetes]** |          | Prediction of type 2 diabetes among patients with visits to psychiatric hospital departments |

[Type 2 diabetes]: https://github.com/Aarhus-Psychiatry-Research/t2d-feature-generation

## 📖 Documentation

| Documentation              |                                                                                    |
| -------------------------- | ---------------------------------------------------------------------------------- |
| 🎛 **[API References]**     | The detailed reference for psycop-feature-generation's API. Including function documentation |
| 🙋 **[FAQ]**                | Frequently asked question                                                          |

[api references]: https://Aarhus-Psychiatry-Research.github.io/psycop-feature-generation/
[FAQ]: https://Aarhus-Psychiatry-Research.github.io/psycop-feature-generation/faq.html

## 💬 Where to ask questions

| Type                           |                        |
| ------------------------------ | ---------------------- |
| 🚨 **Bug Reports**              | [GitHub Issue Tracker] |
| 🎁 **Feature Requests & Ideas** | [GitHub Issue Tracker] |
| 👩‍💻 **Usage Questions**          | [GitHub Discussions]   |
| 🗯 **General Discussion**       | [GitHub Discussions]   |

[github issue tracker]: https://github.com/Aarhus-Psychiatry-Research/psycop-feature-generation/issues
[github discussions]: https://github.com/Aarhus-Psychiatry-Research/psycop-feature-generation/discussions


